---
title: <span class="badge object-type-array"></span> ObjectMatchers
---
# <span class="badge object-type-array"></span> ObjectMatchers

## Definition

```python
ObjectMatchers: typing.TypeAlias = list[alerting.ObjectMatcher]
```
